@@ -34,7 +34,7 @@ class PreviewWidget : public QWidget
     Q_OBJECT
 
 public:
-    PreviewWidget (QWidget *parent=0);
+    PreviewWidget (QWidget *parent=nullptr);
     ~PreviewWidget ();
 
     void setTheme (const XCursorThemeData *theme);
