@@ -39,6 +39,8 @@
 #include <QX11Info>
 #include <X11/Xcursor/Xcursor.h>
 
+#include <QGuiApplication>
+
 const QString HOME_ICON_DIR(QDir::homePath() + QStringLiteral("/.icons"));
 
 SelectWnd::SelectWnd(LXQt::Settings* settings, QWidget *parent)
@@ -48,7 +50,7 @@ SelectWnd::SelectWnd(LXQt::Settings* settings, QWidget *parent)
 {
     ui->setupUi(this);
     ui->warningLabel->hide();
-    ui->preview->setCurrentCursorSize(XcursorGetDefaultSize(QX11Info::display()));
+    ui->preview->setCurrentCursorSize(getDefaultCursorSize());
     ui->preview->setCursorSize(ui->preview->getCurrentCursorSize());
 
     mModel = new XCursorThemeModel(this);
@@ -62,21 +64,17 @@ SelectWnd::SelectWnd(LXQt::Settings* settings, QWidget *parent)
     // Make sure we find out about selection changes
     connect(ui->lbThemes->selectionModel(), &QItemSelectionModel::currentChanged, this, &SelectWnd::currentChanged);
     // display/hide warning label
-    connect(mModel, SIGNAL(modelReset()),
-                    this, SLOT(handleWarning()));
-    connect(mModel, SIGNAL(rowsInserted(const QModelIndex&, int, int)),
-                    this, SLOT(handleWarning()));
-    connect(mModel, SIGNAL(rowsRemoved(const QModelIndex&, int, int)),
-                    this, SLOT(handleWarning()));
+    connect(mModel, &XCursorThemeModel::modelReset, this, &SelectWnd::handleWarning);
+    connect(mModel, &XCursorThemeModel::rowsInserted, this, &SelectWnd::handleWarning);
+    connect(mModel, &XCursorThemeModel::rowsRemoved, this, &SelectWnd::handleWarning);
 
-    connect(ui->warningLabel, SIGNAL(showDirInfo()),
-                    this, SLOT(showDirInfo()));
+    connect(ui->warningLabel, &WarningLabel::showDirInfo, this, &SelectWnd::showDirInfo);
     
     // Set actual cursor size
-    ui->cursorSizeSpinBox->setValue(XcursorGetDefaultSize(QX11Info::display()));
+    ui->cursorSizeSpinBox->setValue(getDefaultCursorSize());
+
     
-    connect(ui->cursorSizeSpinBox, SIGNAL(	valueChanged(int)),
-                    this, SLOT(cursorSizeChaged(int)));
+    connect(ui->cursorSizeSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &SelectWnd::cursorSizeChaged);
 
     // Disable the install button if we can't install new themes to ~/.icons,
     // or Xcursor isn't set up to look for cursor themes there
@@ -186,7 +184,7 @@ void SelectWnd::applyCusorTheme()
     // call xrdb to merge the new settings in ~/.Xdefaults
     // FIXME: need to check if we're running in X?
     QProcess xrdb;
-    xrdb.start(QStringLiteral("xrdb -merge ") + QDir::home().path() + QStringLiteral("/.Xdefaults"));
+    xrdb.start(QStringLiteral("xrdb"), QStringList() << QStringLiteral("-merge") << QDir::home().path() + QStringLiteral("/.Xdefaults"));
     xrdb.waitForFinished();
 
     // old razor-qt and lxqt versions use $XCURSOR_THEME environment variable
