@@ -11,7 +11,7 @@
     <message>
         <location filename="../selectwnd.ui" line="46"/>
         <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
-        <translation>使いたいカーソルテーマを選択して下さい (カーソルをテストするにはマウスをプレビューの上に合わせます)。&lt;b&gt;この変更後に LXQt セッションの再起動が必要です&lt;/b&gt;:</translation>
+        <translation>使いたいカーソルテーマを選択して下さい (カーソルをテストするにはプレビューの上にマウスを合わせます)。&lt;b&gt;この変更後に LXQt セッションを再起動して下さい&lt;/b&gt;:</translation>
     </message>
     <message>
         <location filename="../selectwnd.ui" line="23"/>
@@ -54,7 +54,7 @@
     <message>
         <location filename="../warninglabel.ui" line="44"/>
         <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
-        <translation>カーソルテーマを見つけられませんでした。代わりに、デフォルトの X11 カーソルテーマが使われます。次のディレクトリを探しました:</translation>
+        <translation>カーソルテーマを見つけられませんでした。代わりに、既定の X11 カーソルテーマが使われます。次のディレクトリを探しました:</translation>
     </message>
     <message>
         <location filename="../warninglabel.ui" line="54"/>
