@@ -9,29 +9,39 @@
         <translation>LXQt滑鼠游標主題設定</translation>
     </message>
     <message>
-        <location filename="../selectwnd.ui" line="20"/>
+        <location filename="../selectwnd.ui" line="46"/>
         <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
-        <translation>選擇你想使用的游標主題 (來回移動來測試游標). &lt;b&gt;改變後需重新啟動LXQt會話&lt;/b&gt;：</translation>
+        <translation>選擇你想使用的游標主題 (來回移動來測試游標)。&lt;b&gt;改變後需重新啟動LXQt會話&lt;/b&gt;：</translation>
     </message>
     <message>
-        <location filename="../selectwnd.ui" line="81"/>
+        <location filename="../selectwnd.ui" line="23"/>
         <source>&amp;Install New Theme...</source>
-        <translation>安裝新主題 (&amp;I)...</translation>
+        <translation>安裝新主題(&amp;I)...</translation>
     </message>
     <message>
-        <location filename="../selectwnd.ui" line="88"/>
+        <location filename="../selectwnd.ui" line="72"/>
+        <source>LXQt session needs restart to view this change.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../selectwnd.ui" line="91"/>
         <source>&amp;Remove Theme</source>
         <translation>移除主題(&amp;R)</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="212"/>
+        <location filename="../selectwnd.ui" line="111"/>
+        <source>Size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../selectwnd.cpp" line="233"/>
         <source>XCurTheme error</source>
         <translation>XCurTheme錯誤</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="213"/>
+        <location filename="../selectwnd.cpp" line="234"/>
         <source>You can&apos;t remove active theme!</source>
-        <translation>您無法移除正在套用的主題!</translation>
+        <translation>無法移除正在套用的主題！</translation>
     </message>
 </context>
 <context>
