@@ -36,6 +36,8 @@
 #include <QMetaProperty>
 #include <QMetaEnum>
 #include <QToolBar>
+#include <QGuiApplication>
+
 
 #ifdef Q_WS_X11
 extern void qt_x11_apply_settings_in_all_apps();
@@ -262,6 +264,8 @@ void StyleConfig::applyStyle()
         // GTK3
         themeName = ui->gtk3ComboBox->currentText();
         mConfigOtherToolKits->setGTKConfig(QStringLiteral("3.0"), themeName);
+        if(QGuiApplication::platformName() == QStringLiteral("wayland"))
+            mConfigOtherToolKits->setGsettingsConfig(QStringLiteral("3.0"), themeName);
         // GTK2
         themeName = ui->gtk2ComboBox->currentText();
         mConfigOtherToolKits->setGTKConfig(QStringLiteral("2.0"), themeName);
