@@ -24,7 +24,7 @@
     <message>
         <location filename="../configothertoolkits.cpp" line="149"/>
         <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
-        <translation>&lt;p&gt;&apos;%1&apos; a été écrasé.&lt;/p&gt;&lt;p&gt;Vous pouvez trouver une copie de vos anciens paramètres dans &apos;% 2&apos;&lt;/p&gt;</translation>
+        <translation>&lt;p&gt;&apos;%1&apos; a été écrasé.&lt;/p&gt;&lt;p&gt;Vous pouvez trouver une copie de vos anciens paramètres dans &apos;%2&apos;&lt;/p&gt;</translation>
     </message>
 </context>
 <context>
@@ -245,7 +245,7 @@
     <message>
         <location filename="../styleconfig.ui" line="112"/>
         <source>View:</source>
-        <translation>Voir :</translation>
+        <translation>Vue :</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="122"/>
@@ -280,7 +280,7 @@
     <message>
         <location filename="../styleconfig.ui" line="227"/>
         <source>&amp;Default Palette</source>
-        <translation>Palette par défaut</translation>
+        <translation>Palette par &amp;défaut</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="254"/>
