@@ -6,7 +6,7 @@
     <message>
         <location filename="../colorLabel.cpp" line="37"/>
         <source>Click to change color.</source>
-        <translation>Kattintson a szín megváltoztatásához.</translation>
+        <translation>Kattintson ide a szín megváltoztatásához.</translation>
     </message>
     <message>
         <location filename="../colorLabel.cpp" line="61"/>
@@ -87,7 +87,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="107"/>
         <source>Font hinting style:</source>
-        <translation>A hinting módja:</translation>
+        <translation>A betűjavítás módja:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="118"/>
@@ -113,7 +113,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="141"/>
         <source>Font hinting</source>
-        <translation>Betű hinting</translation>
+        <translation>Betűjavítás</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="148"/>
@@ -123,7 +123,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="155"/>
         <source>Autohint</source>
-        <translation>Automatikus hinting</translation>
+        <translation>Automatikus betűjavítás</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="172"/>
@@ -156,7 +156,7 @@
     <message>
         <location filename="../iconthemeconfig.ui" line="14"/>
         <source>LXQt Appearance Configuration</source>
-        <translation>LXQt megjelenés beállítása</translation>
+        <translation>LXQt megjelenés beállítások</translation>
     </message>
     <message>
         <location filename="../iconthemeconfig.ui" line="26"/>
@@ -171,7 +171,7 @@
     <message>
         <location filename="../iconthemeconfig.ui" line="90"/>
         <source>Colorize icons based on widget style (palette)</source>
-        <translation>Színes ikonok az elemek stílusából (paletta)</translation>
+        <translation>Ikonok színezése az elemstílusból (paletta)</translation>
     </message>
 </context>
 <context>
@@ -192,7 +192,7 @@
     <message>
         <location filename="../main.cpp" line="58"/>
         <source>LXQt Appearance Configuration</source>
-        <translation>LXQt megjelenés beállítása</translation>
+        <translation>LXQt megjelenés beállítások</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="71"/>
@@ -245,7 +245,7 @@
     <message>
         <location filename="../styleconfig.ui" line="112"/>
         <source>View:</source>
-        <translation type="unfinished">Nézet:</translation>
+        <translation>Nézet:</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="122"/>
@@ -265,7 +265,7 @@
     <message>
         <location filename="../styleconfig.ui" line="162"/>
         <source>View Text:</source>
-        <translation type="unfinished">Nézet szövege:</translation>
+        <translation>Nézet szövege:</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="172"/>
@@ -285,7 +285,7 @@
     <message>
         <location filename="../styleconfig.ui" line="254"/>
         <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
-        <translation>Állítsa be a GTK témát (GTK konfigurációs fájlok felül lesznek írva!)</translation>
+        <translation>GTK téma beállítása (A GTK konfigurációs fájlok felül lesznek írva!)</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="274"/>
@@ -302,7 +302,7 @@
         <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
 
 Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
-        <translation>Az egységes témához válasszon hasonló stílust/témát (ha rendelkezésre áll) az összes listán, vagy válassza a &apos;gtk2&apos; Qt stílust (ha rendelkezésre áll) a GTK téma utánzásához.
+        <translation>Az egységes témához válasszon hasonló stílust/témát (ha rendelkezésre áll) az összes listán, vagy válassza a &apos;gtk2&apos; Qt stílust (ha rendelkezésre áll) a GTK téma utánozásához.
 
 Győződjön meg arról, hogy az &apos;xsettingsd&apos; telepítve van, hogy a GTK alkalmazások a menet közben tudjanak témát váltani.</translation>
     </message>
