@@ -24,7 +24,7 @@
     <message>
         <location filename="../configothertoolkits.cpp" line="149"/>
         <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
-        <translation>&lt;p&gt;&apos;%1&apos; は上書きされました。&lt;/p&gt;&lt;p&gt;&apos;%2&apos; の古い設定からコピーをすることができます。&lt;/p&gt;</translation>
+        <translation>&lt;p&gt;&apos;%1&apos; が上書きされました。&lt;/p&gt;&lt;p&gt;&apos;%2&apos; に古い設定のコピーがあります。&lt;/p&gt;</translation>
     </message>
 </context>
 <context>
@@ -37,7 +37,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="30"/>
         <source>Default font for user interface</source>
-        <translation>ユーザーインターフェースのデフォルトのフォント</translation>
+        <translation>ユーザーインターフェースの既定のフォント</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="36"/>
@@ -77,12 +77,12 @@
     <message>
         <location filename="../fontsconfig.ui" line="94"/>
         <source>The following settings only affect newly started applications</source>
-        <translation>以下の設定は、これから新たに実行するアプリケーションに適用されます</translation>
+        <translation>以下の設定は、これから新たに起動するアプリケーションに適用されます</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="100"/>
         <source>Use antialias fonts</source>
-        <translation>アンチエイリアスされたフォントを用いる</translation>
+        <translation>アンチエイリアスのフォントを使用する</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="107"/>
@@ -113,7 +113,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="141"/>
         <source>Font hinting</source>
-        <translation>フォントのヒンティング</translation>
+        <translation>フォントヒンティング</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="148"/>
@@ -128,7 +128,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="172"/>
         <source>Subpixel antialiasing:</source>
-        <translation>サブピクセルアンチエイリアス:</translation>
+        <translation>サブピクセル アンチエイリアス:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="188"/>
@@ -302,9 +302,9 @@
         <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
 
 Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
-        <translation>テーマを統一するには、すべてのリストで類似のスタイルやテーマを(可能ならば)選択するか、GTK テーマを再現するために Qt スタイルで &apos;gtk2&apos; を(可能ならば)選択します。
+        <translation>テーマを統一するには、すべてのリストで類似のスタイルやテーマを (可能ならば) 選択するか、GTK テーマを再現するために Qt スタイルで &apos;gtk2&apos; を (可能ならば) 選択して下さい。
 
-すぐに GTK アプリケーションのテーマに適用されるように、&apos;xsettingsd&apos; がインストールされていることを確認してください。</translation>
+すぐに GTK アプリケーションのテーマに適用されるように、&apos;xsettingsd&apos; がインストールされていることを確認して下さい。</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="311"/>
@@ -334,7 +334,7 @@ Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply the
     <message>
         <location filename="../styleconfig.ui" line="339"/>
         <source>Default</source>
-        <translation>デフォルト</translation>
+        <translation>既定値</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="347"/>
