@@ -145,7 +145,7 @@
     <message>
         <location filename="../mouseconfig.ui" line="30"/>
         <source>Double click interval:</source>
-        <translation>Interval dvojkliku:</translation>
+        <translation>Interval dvojklepnutí:</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="37"/>
@@ -183,7 +183,7 @@
     <message>
         <location filename="../lxqt-config-input.cpp" line="88"/>
         <source>Cursor</source>
-        <translation>Ukazatel</translation>
+        <translation>Ukazovátko</translation>
     </message>
     <message>
         <location filename="../lxqt-config-input.cpp" line="95"/>
