@@ -35,8 +35,8 @@ class FastMenu : public QGroupBox
 
 
 public:
-    FastMenu(KScreen::ConfigPtr config, QWidget* parent = 0);
-    ~FastMenu();
+    FastMenu(KScreen::ConfigPtr config, QWidget* parent = nullptr);
+    ~FastMenu() override;
 
 private Q_SLOTS:
     void onSeleccionChanged(int index);
@@ -46,7 +46,6 @@ private:
     KScreen::ConfigPtr mConfig;
     KScreen::ConfigPtr mOldConfig;
     
-    void extended();
     void unified();
     void onlyFirst();
     void onlySecond();
