@@ -29,9 +29,8 @@
 
 static bool loadSettingsOk(int argc, char** argv)
 {
-    for(int i=0; i<argc; i++)
-    {
-        if(QString(argv[i]) == "-l")
+    for(int i=0; i<argc; i++) {
+        if(QString::fromUtf8(argv[i]) == QLatin1String("-l"))
             return true;
     }
     return false;
@@ -39,11 +38,13 @@ static bool loadSettingsOk(int argc, char** argv)
 
 int main(int argc, char** argv)
 {
-    if( loadSettingsOk(argc, argv) )
-    {
+    if( loadSettingsOk(argc, argv) ) {
         // If -l option is provided, settings are loaded and app is closed.
         QGuiApplication app(argc, argv);
         LoadSettings load;
+        load.applyBestSettings();
+        qDebug() << "[load.applyBestSettings()] Finished";
+        //QCoreApplication::instance()->exit(0);
         return app.exec();
     }
 
@@ -57,10 +58,8 @@ int main(int argc, char** argv)
                                            "\nliblxqt   " LXQT_VERSION
                                            "\nQt        " QT_VERSION_STR);
     app.setApplicationVersion(VERINFO);
-    QCommandLineOption loadOption(QStringList() << "l" << "loadlast",
-            app.tr("Load last settings."));
-    parser.addOption(loadOption);
-    QCommandLineOption helpOption = parser.addHelpOption();
+    QCommandLineOption loadOption(QStringList() << QStringLiteral("l") << QStringLiteral("loadlast"),
+                                  app.tr("Load last settings."));
     parser.addOption(loadOption);
     parser.addVersionOption();
     parser.addHelpOption();
@@ -70,14 +69,14 @@ int main(int argc, char** argv)
 
     MonitorSettingsDialog dlg;
     app.setActivationWindow(&dlg);
-    dlg.setWindowIcon(QIcon::fromTheme("preferences-desktop-display"));
+    dlg.setWindowIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-display")));
     dlg.show();
 
     int ok = app.exec();
-    
+
     // FIXME: kscreen backend doesn't close properly.
     //system("killall kscreen_backend_launcher");
-    
+
     return ok;
 
 }
