@@ -34,7 +34,7 @@
     <message>
         <location filename="../loadsettings.cpp" line="97"/>
         <source>Default monitor settings has been applied. If you want change monitors settings, please, use lxqt-config-monitor.</source>
-        <translation>A monitor alapértelmezett beállítása lettek alkalmazva. Ha módosítani szeretné a monitorok beállításait, használja az lxqt-config-monitor alkalmazást.</translation>
+        <translation>Az alapértelmezett monitorbeállítások lettek alkalmazva. Ha módosítani szeretné a monitorok beállításait, használja az lxqt-config-monitor alkalmazást.</translation>
     </message>
 </context>
 <context>
@@ -72,7 +72,7 @@
     <message>
         <location filename="../managesavedsettings.cpp" line="65"/>
         <source>Left</source>
-        <translation>Bal</translation>
+        <translation>Balra</translation>
     </message>
     <message>
         <location filename="../managesavedsettings.cpp" line="68"/>
@@ -82,7 +82,7 @@
     <message>
         <location filename="../managesavedsettings.cpp" line="71"/>
         <source>Right</source>
-        <translation>Jobb</translation>
+        <translation>Jobbra</translation>
     </message>
     <message>
         <location filename="../managesavedsettings.cpp" line="75"/>
@@ -112,7 +112,7 @@
     <message>
         <location filename="../monitorpicture.ui" line="27"/>
         <source>Keep monitors attached</source>
-        <translation>Monitorok csatlakozva maradnak</translation>
+        <translation>Monitorok csatlakozva tartása</translation>
     </message>
 </context>
 <context>
@@ -198,7 +198,7 @@
     <message>
         <location filename="../monitorwidget.ui" line="176"/>
         <source>Info</source>
-        <translation>Információk</translation>
+        <translation>Információ</translation>
     </message>
     <message>
         <location filename="../monitorwidget.ui" line="182"/>
@@ -260,12 +260,12 @@
     <message>
         <location filename="../monitorwidget.cpp" line="155"/>
         <source>Right</source>
-        <translation>Jobb</translation>
+        <translation>Jobbra</translation>
     </message>
     <message>
         <location filename="../monitorwidget.cpp" line="156"/>
         <source>Inverted</source>
-        <translation>Inverz</translation>
+        <translation>Megfordítva</translation>
     </message>
     <message>
         <location filename="../monitorwidget.cpp" line="244"/>
@@ -304,7 +304,7 @@
     <message>
         <location filename="../timeoutdialog.ui" line="46"/>
         <source>Are the current settings OK for you?</source>
-        <translation>Megfelelőek a beállítások?</translation>
+        <translation>Megfelelőek a jelenlegi beállítások?</translation>
     </message>
     <message numerus="yes">
         <location filename="../timeoutdialog.cpp" line="63"/>
@@ -312,6 +312,7 @@
         <translatorcomment>%n másodperc van hátra</translatorcomment>
         <translation>
             <numerusform>%n másodperc van hátra</numerusform>
+            <numerusform>%n másodperc van hátra</numerusform>
         </translation>
     </message>
 </context>
