@@ -80,17 +80,17 @@ class ConfigPaneModel: public QAbstractListModel
 public:
     ConfigPaneModel(): QAbstractListModel()
     {
-        QString menuFile = XdgMenu::getMenuFileName("config.menu");
+        QString menuFile = XdgMenu::getMenuFileName(QStringLiteral("config.menu"));
         XdgMenu xdgMenu;
-        xdgMenu.setEnvironments(QStringList() << "X-LXQT" << "LXQt" << "LXDE");
+        xdgMenu.setEnvironments(QStringList() << QStringLiteral("X-LXQT") << QStringLiteral("LXQt") << QStringLiteral("LXDE"));
         bool res = xdgMenu.read(menuFile);
         if (!res)
         {
-            QMessageBox::warning(0, "Parse error", xdgMenu.errorString());
+            QMessageBox::warning(nullptr, QStringLiteral("Parse error"), xdgMenu.errorString());
             return;
         }
 
-        DomElementIterator it(xdgMenu.xml().documentElement() , "Menu");
+        DomElementIterator it(xdgMenu.xml().documentElement() , QStringLiteral("Menu"));
         while(it.hasNext())
         {
             this->buildGroup(it.next());
@@ -100,21 +100,21 @@ public:
     void buildGroup(const QDomElement& xml)
     {
         QString category;
-        if (! xml.attribute("title").isEmpty())
-            category = xml.attribute("title");
+        if (! xml.attribute(QStringLiteral("title")).isEmpty())
+            category = xml.attribute(QStringLiteral("title"));
         else
-            category = xml.attribute("name");
+            category = xml.attribute(QStringLiteral("name"));
 
-        DomElementIterator it(xml , "AppLink");
+        DomElementIterator it(xml , QStringLiteral("AppLink"));
         while(it.hasNext())
         {
             QDomElement x = it.next();
 
             XdgDesktopFile xdg;
-            xdg.load(x.attribute("desktopFile"));
+            xdg.load(x.attribute(QStringLiteral("desktopFile")));
 
             ConfigPane pane;
-            pane.id() = xdg.value("Icon").toString();
+            pane.id() = xdg.value(QStringLiteral("Icon")).toString();
             pane.category() = category;
             pane.setXdg(xdg);
             m_list.append(pane);
@@ -128,19 +128,21 @@ public:
         m_list[index.row()].xdg().startDetached();
     }
 
-    ~ConfigPaneModel() { }
+    ~ConfigPaneModel() override { }
 
-    int rowCount(const QModelIndex &parent = QModelIndex()) const
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override
     {
+        Q_UNUSED(parent)
         return m_list.count();
     }
 
-    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole)
+    bool setData(const QModelIndex &, const QVariant &, int role = Qt::EditRole) override
     {
+        Q_UNUSED(role)
         return false;
     }
 
-    QVariant data(const QModelIndex &index, int role) const
+    QVariant data(const QModelIndex &index, int role) const override
     {
         if (role == Qt::DisplayRole || role == Qt::ToolTipRole)
             return m_list[index.row()].xdg().name();
@@ -168,9 +170,9 @@ class ConfigItemDelegate : public QStyledItemDelegate
 {
 public:
     ConfigItemDelegate(QCategorizedView* view) : mView(view) { }
-    ~ConfigItemDelegate() { }
+    ~ConfigItemDelegate() override { }
 
-    QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
+    QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const override
     {
         /* We let Qt calculate the real cell size but consider the 4-px margin
            around each cell and try to add a 2-px margin around the selection
@@ -185,7 +187,7 @@ public:
     }
 
 protected:
-    void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const
+    void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const override
     {
         if(!index.isValid())
             return;
@@ -194,16 +196,9 @@ protected:
         initStyleOption(&opt, index);
 
         const QSize & iconSize = option.decorationSize;
-        QSize size(mView->gridSize().width() - 8, // 4-px margin around each cell
-                   iconSize.height());
-        // for having sharp non-scalable icons with HDPI
-        int dpr = qApp->devicePixelRatio();
-        if (dpr < 1) dpr = 1;
-        QPixmap pixmap = opt.icon.pixmap(iconSize / dpr); // -> Qt doc -> QIcon::pixmap()
-        if (dpr > 1 && pixmap.size() == iconSize) // exceptional (scalable or not from icon set)
-            pixmap = opt.icon.pixmap(iconSize);
-        opt.icon = QIcon(pixmap.copy(QRect(QPoint(0, 0), size * dpr)));
-        opt.decorationSize = size;
+        int size = qMin(mView->gridSize().width() - 8, // 4-px margin around each cell
+                        iconSize.height());
+        opt.decorationSize = QSize(size, size);
 
         const QWidget* widget = opt.widget;
         QStyle* style = widget ? widget->style() : QApplication::style();
@@ -305,11 +300,6 @@ void LXQtConfig::MainWindow::setSizing()
 {
     // consult the style to know the icon size
     int iconSize = qBound(16, view->decorationSize().height(), 256);
-    // DPR is automatically taken into account in setIconSize()
-    // but wee need to consider it explicitly below
-    int dpr = qApp->devicePixelRatio();
-    if (dpr < 1) dpr = 1;
-    iconSize *= dpr;
     /* To have an appropriate grid size, we suppose that
      *
      * (1) The text has 3 lines and each line has 16 chars (for languages like German), at most;
